%define major 2
%define minor 1
%define fix 11
%define so_ver 7

Name: libevent
Version: %{major}.%{minor}.%{fix}
Release: 1
License: BSD-3-Clause
Summary: event notification library
Url: http://libevent.org

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: openssl-devel >= 1.1.0
BuildRequires: libutil-devel
BuildRequires: python3

Source0: https://github.com/libevent/libevent/releases/download/release-%{version}-stable/libevent-%{version}-stable.tar.gz

%description
libevent is meant to replace the event loop found in event driven network
servers. An application just needs to call event_dispatch() and then add or
remove events dynamically without having to change the event loop.

Currently, libevent supports /dev/poll, kqueue(2), event ports, POSIX select(2),
Windows select(), poll(2), and epoll(4). The internal event mechanism is
completely independent of the exposed event API, and a simple update of
libevent can provide new functionality without having to redesign the
applications. As a result, Libevent allows for portable application development
and provides the most scalable event notification mechanism available on an
operating system. Libevent can also be used for multi-threaded applications,
either by isolating each event_base so that only a single thread accesses it,
or by locked access to a single shared event_base. Libevent should compile on
Linux, *BSD, Mac OS X, Solaris, Windows, and more.

%package -n libevent-%{major}_%{minor}-%{so_ver}
Summary: libevent library
Provides: %{name} = %{version}

%description -n libevent-%{major}_%{minor}-%{so_ver}
libevent libraries

%package devel
Summary: libevent development files
Requires: %{name} = %{version}

%description devel
libevent development files

%prep
%setup -q -n libevent-%{version}-stable

./autogen.sh

2to3 --write --nobackups --no-diffs event_rpcgen.py
perl -p -i -e 's|#!.*|#!'"%{_bindir}/python3|" event_rpcgen.py

%build

%configure \
  CPPFLAGS="-I%{_includedir}" \
  LDFLAGS="-Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  --with-aix-soname=svr4 \
  --disable-clock-gettime \
  --enable-shared \
  --disable-static \
  # end

%make_build

%install

%make_install

find %{buildroot}/%{_libdir} -name \*.la | xargs rm

%files -n libevent-%{major}_%{minor}-%{so_ver}
%defattr(-, qsys, *none)

%{_libdir}/libevent_openssl-%{major}.%{minor}.so.%{so_ver}
%{_libdir}/libevent_extra-%{major}.%{minor}.so.%{so_ver}
%{_libdir}/libevent_pthreads-%{major}.%{minor}.so.%{so_ver}
%{_libdir}/libevent-%{major}.%{minor}.so.%{so_ver}
%{_libdir}/libevent_core-%{major}.%{minor}.so.%{so_ver}

%files devel
%defattr(-, qsys, *none)

%{_bindir}/event_rpcgen.py

%{_libdir}/libevent.so
%{_libdir}/libevent_pthreads.so
%{_libdir}/libevent_extra.so
%{_libdir}/libevent_openssl.so
%{_libdir}/libevent_core.so

%{_libdir}/pkgconfig/libevent_extra.pc
%{_libdir}/pkgconfig/libevent_pthreads.pc
%{_libdir}/pkgconfig/libevent_core.pc
%{_libdir}/pkgconfig/libevent.pc
%{_libdir}/pkgconfig/libevent_openssl.pc

%{_includedir}/evdns.h
%{_includedir}/event2
%{_includedir}/evutil.h
%{_includedir}/evrpc.h
%{_includedir}/event.h
%{_includedir}/evhttp.h

%changelog
* Tue Mar 03 2020 Kevin Adler <kadler@us.ibm.com> - 2.1.11
- Bump to 2.1.11
- libevent 2.1.11 changed ABI and uses sover 7, from 6
- Convert event_rpcgen.py to Python 3

* Tue Dec 3 2019 Abdirahim Musse <abdirahim.musse@ibm.com>
- Use openssl 1.1.0 or greater

* Mon Dec 2 2019 Abdirahim Musse <abdirahim.musse@ibm.com>
- Use SPDX license identifier
- Wrapped description such that each line does not exceed 80 characters
- General Cleanup

* Sat Mar 3 2018 Kevin Adler <kadler@us.ibm.com>
- Add build requirements
- Fix libevent build

* Wed Dec 20 2017 Kevin Adler <kadler@us.ibm.com> 
- Remove 64-bit GCC script workarounds

* Tue Nov 21 2017 Kevin Adler <kadler@us.ibm.com> 
- Remove unused svr4_shlib.sh and old TODOs

* Thu Aug 24 2017 Kevin Adler <kadler@us.ibm.com> 
- Add missing file ownership

* Thu Apr 20 2017 Kevin Adler <kadler@us.ibm.com> 
- Add initial spec file
